@@ -198,7 +198,7 @@ public:
 };
 
 class KMPLAYER_NO_EXPORT ImageRuntime : public TQObject,public MediaTypeRuntime {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ImageRuntime (NodePtr e);
