@@ -73,7 +73,7 @@ typedef std::vector <FFServerSetting *> FFServerSettingList;
 
 
 class KMPLAYER_NO_EXPORT KMPlayerPrefBroadcastPage : public TQFrame {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerPrefBroadcastPage (TQWidget * parent);
@@ -88,7 +88,7 @@ public:
 };
 
 class KMPLAYER_NO_EXPORT KMPlayerPrefBroadcastFormatPage : public TQFrame {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerPrefBroadcastFormatPage (TQWidget * parent, FFServerSettingList &);
@@ -154,7 +154,7 @@ private:
  * Preference page for ffserver
  */
 class KMPLAYER_NO_EXPORT KMPlayerBroadcastConfig : public TQObject, public KMPlayer::PreferencesPage {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerBroadcastConfig (KMPlayer::PartBase * player, KMPlayerFFServerConfig * fsc);
