@@ -94,7 +94,7 @@ public:
  * Class for storing all actual settings and reading/writing them
  */
 class KMPLAYER_EXPORT Settings : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Settings (PartBase *, TDEConfig * part);
