@@ -257,7 +257,7 @@ static const char * blue_xpm[] = {
 
 static TQPushButton * ctrlButton (TQWidget * w, TQBoxLayout * l, const char ** p, int key = 0) {
     TQPushButton * b = new TQPushButton (TQIconSet (TQPixmap(p)), TQString (), w);
-    b->setFocusPolicy (TQ_NoFocus);
+    b->setFocusPolicy (TQWidget::NoFocus);
     b->setFlat (true);
     if (key)
         b->setAccel (TQKeySequence (key));
@@ -268,7 +268,7 @@ static TQPushButton * ctrlButton (TQWidget * w, TQBoxLayout * l, const char ** p
 KDE_NO_CDTOR_EXPORT
 KMPlayerMenuButton::KMPlayerMenuButton (TQWidget * parent, TQBoxLayout * l, const char ** p, int key)
  : TQPushButton (TQIconSet (TQPixmap(p)), TQString (), parent, "kde_kmplayer_control_button") {
-   setFocusPolicy (TQ_NoFocus);
+   setFocusPolicy (TQWidget::NoFocus);
    setFlat (true);
    if (key)
        setAccel (TQKeySequence (key));
