@@ -40,7 +40,7 @@ class PartBase;
  * Class for a certain media, like URL, DVD, TV etc
  */
 class KMPLAYER_EXPORT Source : public TQObject, public PlayListNotify {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Source (const TQString & name, PartBase * player, const char * src);
