@@ -298,14 +298,14 @@ KDE_NO_EXPORT void TVDevice::updateDevicePage () {
         bool ok;
         if (input->getAttribute ("tuner").toInt (&ok) && ok) {
             TQWidget * widget = device_page->inputsTab->page (i);
-            TQTable * table = static_cast <TQTable *> (TQT_TQWIDGET(widget->child ("PageTVChannels", TQTABLE_OBJECT_NAME_STRING)));
+            TQTable * table = static_cast <TQTable *> (TQT_TQWIDGET(widget->child ("PageTVChannels", "TQTable")));
             if (table) {
                 input->clearChildren ();
                 for (int j = 0; j<table->numRows() && table->item (j, 1); ++j) {
                     input->appendChild (new TVChannel (m_doc, table->item (j, 0)->text (), table->item (j, 1)->text ().toDouble ()));
                 }
             }
-            TQComboBox * norms = static_cast <TQComboBox *> (TQT_TQWIDGET(widget->child ("PageTVNorm", TQCOMBOBOX_OBJECT_NAME_STRING)));
+            TQComboBox * norms = static_cast <TQComboBox *> (TQT_TQWIDGET(widget->child ("PageTVNorm", "TQComboBox")));
             if (norms) {
                 input->setAttribute ("norm", norms->currentText ());
             }
