@@ -48,7 +48,7 @@ class TDEConfig;
 
 
 class KMPLAYER_NO_EXPORT TVDevicePage : public TQFrame {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     TVDevicePage (TQWidget *parent, KMPlayer::NodePtr dev);
@@ -68,7 +68,7 @@ private slots:
 };
 
 class KMPLAYER_NO_EXPORT KMPlayerPrefSourcePageTV : public TQFrame {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerPrefSourcePageTV (TQWidget *parent, KMPlayerTVSource *);
@@ -146,7 +146,7 @@ public:
  * Source form scanning TV devices
  */
 class KMPLAYER_NO_EXPORT TVDeviceScannerSource : public KMPlayer::Source {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     TVDeviceScannerSource (KMPlayerTVSource * src);
@@ -178,7 +178,7 @@ private:
  * Source form TV devices, also implementing preference page for it
  */
 class KMPLAYER_NO_EXPORT KMPlayerTVSource : public KMPlayerMenuSource, public KMPlayer::PreferencesPage {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerTVSource (KMPlayerApp * app, TQPopupMenu * m);
