@@ -218,7 +218,7 @@ KDE_NO_EXPORT void View::init (TDEActionCollection * action_collection) {
     m_widgetstack->addWidget (m_multiedit);
     m_widgetstack->addWidget (m_widgettypes[WT_Picture]);
 
-    setFocusPolicy (TQ_ClickFocus);
+    setFocusPolicy (TQWidget::ClickFocus);
 
     setAcceptDrops (true);
     m_view_area->resizeEvent (0L);
@@ -228,7 +228,7 @@ KDE_NO_EXPORT void View::init (TDEActionCollection * action_collection) {
 
 KDE_NO_CDTOR_EXPORT View::~View () {
     delete m_image;
-    if (TQT_BASE_OBJECT(m_view_area->parent ()) != TQT_BASE_OBJECT(this))
+    if (m_view_area->parent() != this)
         delete m_view_area;
 }
 
