@@ -76,7 +76,7 @@ public:
  * The playlist GUI
  */
 class KMPLAYER_EXPORT PlayListView : public TDEListView {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum Flags {
